@@ -42,18 +42,18 @@
 
 #include <getopt.h>
 
-void error_callback(const char *msg, void *) {
+static void error_callback(const char *msg, void *) {
   (void)msg;
 }
-void warning_callback(const char *msg, void *) {
+static void warning_callback(const char *msg, void *) {
   (void)msg;
 }
-void info_callback(const char *msg, void *) {
+static void info_callback(const char *msg, void *) {
   (void)msg;
 }
 
 template <typename T>
-unsigned int readvector(std::vector<T> &v, const char *str)
+static unsigned int readvector(std::vector<T> &v, const char *str)
 {
   if( !str ) return 0;
   std::istringstream os( str );
@@ -67,7 +67,7 @@ unsigned int readvector(std::vector<T> &v, const char *str)
   return (unsigned int)v.size();
 }
 
-int No_Of_Resolutions(const char *filename)
+static int No_Of_Resolutions(const char *filename)
 {
   std::ifstream is;
   is.open( filename, std::ios::binary );
@@ -153,7 +153,7 @@ int No_Of_Resolutions(const char *filename)
 
 }
 
-bool Write_Resolution(gdcm::StreamImageWriter & theStreamWriter, const char *filename, int res, std::ostream& of, int flag,  gdcm::SequenceOfItems *sq)
+static bool Write_Resolution(gdcm::StreamImageWriter & theStreamWriter, const char *filename, int res, std::ostream& of, int flag,  gdcm::SequenceOfItems *sq)
 {
   (void)of;
   std::ifstream is;
@@ -239,8 +239,8 @@ bool Write_Resolution(gdcm::StreamImageWriter & theStreamWriter, const char *fil
        std::cout << "\n No of Resolutions"<< tccp->numresolutions << "\n";
    */
   //opj_j2k_t* j2k = NULL;
-  opj_jp2_t* jp2 = NULL;
-  jp2 = (opj_jp2_t*)dinfo->jp2_handle;
+  //opj_jp2_t* jp2 = NULL;
+  //jp2 = (opj_jp2_t*)dinfo->jp2_handle;
   //int reversible = jp2->j2k->cp->tcps->tccps->qmfbid;
   //std:: cout << reversible;
   int Dimensions[2];
@@ -468,7 +468,7 @@ bool Write_Resolution(gdcm::StreamImageWriter & theStreamWriter, const char *fil
 
 }
 
-bool StreamImageRead_Write(gdcm::StreamImageWriter & theStreamWriter,gdcm::StreamImageReader & reader, int resolution, std::ostream& of, int tile,std::vector<unsigned int> start, std::vector<unsigned int> end)
+static bool StreamImageRead_Write(gdcm::StreamImageWriter & theStreamWriter,gdcm::StreamImageReader & reader, int resolution, std::ostream& of, int tile,std::vector<unsigned int> start, std::vector<unsigned int> end)
 {
   (void)of;
   gdcm::File file1 = reader.GetFile();
@@ -625,7 +625,7 @@ bool StreamImageRead_Write(gdcm::StreamImageWriter & theStreamWriter,gdcm::Strea
 }
 
 
-bool Different_Resolution_From_DICOM( gdcm::StreamImageWriter & theStreamWriter, const char *filename, std::ostream& of, int res, int tile,std::vector<unsigned int> start, std::vector<unsigned int> end)
+static bool Different_Resolution_From_DICOM( gdcm::StreamImageWriter & theStreamWriter, const char *filename, std::ostream& of, int res, int tile,std::vector<unsigned int> start, std::vector<unsigned int> end)
 {
   //std::vector<std::string>::const_iterator it = filenames.begin();
   gdcm::StreamImageReader reader;
@@ -780,7 +780,7 @@ bool Different_Resolution_From_DICOM( gdcm::StreamImageWriter & theStreamWriter,
 
 
 
-bool Different_Resolution_From_jp2( gdcm::StreamImageWriter & theStreamWriter, const char *filename, std::ostream& of, int nres)
+static bool Different_Resolution_From_jp2( gdcm::StreamImageWriter & theStreamWriter, const char *filename, std::ostream& of, int nres)
 {
   //std::vector<std::string>::const_iterator it = filenames.begin();
   bool b = true;
@@ -806,20 +806,20 @@ bool Different_Resolution_From_jp2( gdcm::StreamImageWriter & theStreamWriter, c
 
 
 
-void PrintVersion()
+static void PrintVersion()
 {
   std::cout << "gdcmstream: gdcm " << gdcm::Version::GetVersion() << " ";
   const char date[] = "$Date$";
   std::cout << date << std::endl;
 }
 
-void PrintHelp()
+static void PrintHelp()
 {
   PrintVersion();
   std::cout << "Usage: gdcmstream [OPTION] input.dcm output.dcm" << std::endl;
 }
 
-void end_of_WSIFile(std::ostream& of)
+static void end_of_WSIFile(std::ostream& of)
 {
   uint16_t firstTag1 =  0xfffe;
   uint16_t secondTag1 = 0xe0dd;
@@ -892,7 +892,7 @@ int main (int argc, char *argv[])
       {
     case 0:
         {
-        const char *s = long_options[option_index].name;(void)s;
+        const char *s = long_options[option_index].name; (void)s;
 
         //printf ("option %s", s);
         if (optarg)
