@@ -2,7 +2,7 @@
 
   Program: GDCM (Grassroots DICOM). A DICOM library
 
-  Copyright (c) 2006-2011 Mathieu Malaterre
+  Copyright (c) 2006-2016 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -22,7 +22,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
+#include <string.h> // strspn
 #include <assert.h>
 #include <errno.h>
 #include <sys/stat.h>
@@ -43,9 +43,7 @@
 #define snprintf _snprintf
 #endif
 #ifdef __APPLE__
-#include <CoreFoundation/CFBase.h>
-#include <CoreFoundation/CFBundle.h>
-#include <CoreFoundation/CFURL.h>
+#include <CoreFoundation/CoreFoundation.h>
 #endif // __APPLE__
 
 #if defined(_WIN32) && (defined(_MSC_VER) || defined(__WATCOMC__) ||defined(__BORLANDC__) || defined(__MINGW32__))
@@ -398,51 +396,6 @@ size_t System::FileSize(const char* filename)
   return size2;
 }
 
-#if 0
-const char *System::GetCurrentDataDirectory()
-{
-#ifdef _WIN32
-  static char path[MAX_PATH];
-  gdcm::Filename fn( GetCurrentProcessFileName() );
-  if ( !fn.IsEmpty() )
-    {
-    std::string str = fn.GetPath();
-    str += "/../" GDCM_INSTALL_DATA_DIR;
-    strcpy(path, str.c_str());
-    return path;
-    }
-#else
-
-  static char path[PATH_MAX];
-
-#ifdef __APPLE__
-  Boolean success = false;
-  CFURLRef pathURL = CFBundleCopyResourcesDirectoryURL(CFBundleGetMainBundle());
-  if (pathURL != NULL)
-    {
-    success = CFURLGetFileSystemRepresentation(pathURL, true /*resolveAgainstBase*/, (unsigned char*) path, PATH_MAX);
-    CFRelease(pathURL);
-    }
-  if (success)
-    {
-    strncat(path, "/" GDCM_INSTALL_DATA_DIR, PATH_MAX);
-    return path;
-    }
-#endif
-
-  gdcm::Filename fn( GetCurrentProcessFileName() );
-  if ( !fn.IsEmpty() )
-    {
-    std::string str = fn.GetPath();
-    str += "/../" GDCM_INSTALL_DATA_DIR;
-    strcpy(path, str.c_str());
-    return path;
-    }
-#endif
-  return 0;
-}
-#endif
-
 /*
  * TODO:
  * check cygwin
@@ -450,9 +403,6 @@ const char *System::GetCurrentDataDirectory()
  * check solaris
  * check hpux
  * check os2: DosGetInfoBlocks / DosQueryModuleName
- * check macosx :
- *  ProcessSerialNumber psn = {kNoProcess, kCurrentProcess};
- *  GetProcessInformation -> FSMakeFSSpec
  * ...
  */
 const char *System::GetCurrentProcessFileName()
@@ -464,7 +414,6 @@ const char *System::GetCurrentProcessFileName()
     return buf;
     }
 #elif defined(__APPLE__)
-  //  _NSGetExecutablePath()
   static char buf[PATH_MAX];
   Boolean success = false;
   CFURLRef pathURL = CFBundleCopyExecutableURL(CFBundleGetMainBundle());
@@ -544,7 +493,7 @@ const char *System::GetCurrentResourcesDirectory()
     }
   if (success)
     {
-    strncat(path, "/" GDCM_INSTALL_DATA_DIR, PATH_MAX);
+    strlcat(path, "/" GDCM_INSTALL_DATA_DIR, PATH_MAX);
     return path;
     }
 #endif
@@ -778,15 +727,24 @@ const char *System::GetTimezoneOffsetFromUTC()
 bool System::FormatDateTime(char date[22], time_t timep, long milliseconds)
 {
   // \precondition
-  if( !(milliseconds >= 0 && milliseconds < 1000000) ) return false;
+  if( !(milliseconds >= 0 && milliseconds < 1000000) )
+    {
+    return false;
+    }
 
   // YYYYMMDDHHMMSS.FFFFFF&ZZXX
-  if(!date) return false;
+  if(!date)
+    {
+    return false;
+    }
   const size_t maxsize = 40;
   char tmp[maxsize];
   // Obtain the time of day, and convert it to a tm struct.
   struct tm *ptm = localtime (&timep);
-  if(!ptm) return false;
+  if(!ptm)
+    {
+    return false;
+    }
   // Format the date and time, down to a single second.
   size_t ret = strftime (tmp, sizeof (tmp), "%Y%m%d%H%M%S", ptm);
   assert( ret == 14 );
@@ -797,10 +755,9 @@ bool System::FormatDateTime(char date[22], time_t timep, long milliseconds)
 
   // Add milliseconds
   const size_t maxsizall = 22;
-  //char tmpAll[maxsizall];
-  int ret2 = snprintf(date,maxsizall,"%s.%06ld",tmp,milliseconds);
-  assert( ret2 >= 0 );
-  if( (unsigned int)ret2 >= maxsizall )
+  const int ret2 = snprintf(date,maxsizall,"%s.%06ld",tmp,milliseconds);
+  if( ret2 < 0 ) return false;
+  if( (size_t)ret2 >= maxsizall )
     {
     return false;
     }
@@ -933,40 +890,56 @@ bool System::GetHostName(char name[255])
   return false;
 }
 
-char *System::StrTokR(char *ptr, const char *sep, char **end)
+char *System::StrTokR(char *str, const char *delim, char **nextp)
 {
 #if 1
-  if (ptr == NULL)
+  // http://groups.google.com/group/comp.lang.c/msg/2ab1ecbb86646684
+  // PD -> http://groups.google.com/group/comp.lang.c/msg/7c7b39328fefab9c
+  char *ret;
+
+  if (str == NULL)
     {
-    ptr = *end;
+    str = *nextp;
     }
 
-  /* search string for set of char: strspn */
-  while (*ptr && strchr(sep, *ptr))
+  str += strspn(str, delim);
+
+  if (*str == '\0')
     {
-    ++ptr;
+    return NULL;
     }
 
-  if (*ptr == '\0') return NULL;
+  ret = str;
 
-  char *token = ptr;
-  *end = token + 1;
+  str += strcspn(str, delim);
 
-  char *pend = *end;
-  while (*pend && !strchr(sep, *pend))
+  if (*str)
     {
-    ++pend;
+    *str++ = '\0';
     }
 
-  if (*pend)
-    {
-    *pend = '\0';
-    ++pend;
-    }
+  *nextp = str;
 
-  return token;
+  return ret;
 #else
-  return strtok_r(ptr,sep,end);
+  return strtok_r(str,delim,nextp);
+#endif
+}
+
+char *System::StrSep(char **sp, const char *sep)
+{
+  // http://unixpapa.com/incnote/string.html
+  // http://stackoverflow.com/questions/8512958/is-there-a-windows-variant-of-strsep
+#if 1
+  char *p, *s;
+  if (sp == NULL || *sp == NULL || **sp == '\0') return NULL;
+  s = *sp;
+  p = s + strcspn(s, sep);
+  if (*p != '\0') *p++ = '\0';
+  *sp = p;
+  return s;
+#else
+  return strsep(sp, sep);
 #endif
 }
 
