@@ -27,7 +27,7 @@
 #include <vector>
 #include <sstream>
 
-namespace gdcm
+namespace gdcm_ns
 {
 
 struct void_;
@@ -764,7 +764,7 @@ public:
 
 
 // For particular case for ASCII string
-// WARNING: This template explicitely instanciates a particular
+// WARNING: This template explicitly instanciates a particular
 // EncodingImplementation THEREFORE it is required to be declared after the
 // EncodingImplementation is needs (doh!)
 #if 0
@@ -1045,6 +1045,6 @@ public:
  * This is a C++ example on how to use gdcm::Attribute
  */
 
-} // namespace gdcm
+} // namespace gdcm_ns
 
 #endif //GDCMATTRIBUTE_H
