@@ -14,7 +14,7 @@
 #include "gdcmDataSet.h"
 #include "gdcmPrivateTag.h"
 
-namespace gdcm
+namespace gdcm_ns
 {
 DataElement DataSet::DEEnd = DataElement( Tag(0xffff,0xffff) );
 
@@ -148,9 +148,9 @@ MediaStorage DataSet::GetMediaStorage() const
   MediaStorage ms = MediaStorage::GetMSType(ts.c_str());
   if( ms == MediaStorage::MS_END )
     {
-    gdcmWarningMacro( "Media Storage Class UID: " << ts << " is unknow" );
+    gdcmWarningMacro( "Media Storage Class UID: " << ts << " is unknown" );
     }
   return ms;
 }
 
-} // end namespace gdcm
+} // end namespace gdcm_ns
