@@ -109,7 +109,7 @@ void IconImageFilter::ExtractIconImages()
       PhotometricInterpretation pi(
         PhotometricInterpretation::GetPIType(
           photometricinterpretation_str.c_str()));
-      assert( pi != PhotometricInterpretation::UNKNOW);
+      assert( pi != PhotometricInterpretation::UNKNOWN);
       pixeldata.SetPhotometricInterpretation( pi );
 
       //
@@ -157,10 +157,10 @@ void IconImageFilter::ExtractIconImages()
               (unsigned char*)lut_raw->GetPointer(), lut_raw->GetLength() );
             //assert( pf.GetBitsAllocated() == el_us3.GetValue(2) );
 
-            unsigned long check =
-              (el_us3.GetValue(0) ? el_us3.GetValue(0) : 65536)
-              * el_us3.GetValue(2) / 8;
-            assert( check == lut_raw->GetLength() ); (void)check;
+            //unsigned long check =
+            //  (el_us3.GetValue(0) ? el_us3.GetValue(0) : 65536)
+            //  * el_us3.GetValue(2) / 8;
+            //assert( check == lut_raw->GetLength() ); (void)check;
             }
           else if( ds.FindDataElement( seglut ) )
             {
@@ -287,7 +287,7 @@ void IconImageFilter::ExtractIconImages()
     PhotometricInterpretation pi(
       PhotometricInterpretation::GetPIType(
         photometricinterpretation_str.c_str()));
-    assert( pi != PhotometricInterpretation::UNKNOW);
+    assert( pi != PhotometricInterpretation::UNKNOWN);
     pixeldata.SetPhotometricInterpretation( pi );
     const Tag tpixeldata = Tag(0x7fe0, 0x0010);
     assert( ds.FindDataElement( tpixeldata ) );
@@ -321,7 +321,7 @@ void IconImageFilter::ExtractIconImages()
       const ByteValue *bv = de.GetByteValue();
       assert( bv );
       is.str( std::string( bv->GetPointer(), bv->GetLength() ) );
-      gdcm::TransferSyntax jpegts;
+      TransferSyntax jpegts;
       JPEGCodec jpeg;
       jpeg.SetPixelFormat( pf1 ); // important to initialize
       bool b = jpeg.GetHeaderInfo( is, jpegts );
@@ -425,7 +425,7 @@ void IconImageFilter::ExtractIconImages()
     PhotometricInterpretation pi(
       PhotometricInterpretation::GetPIType(
         photometricinterpretation_str.c_str()));
-    assert( pi != PhotometricInterpretation::UNKNOW);
+    assert( pi != PhotometricInterpretation::UNKNOWN);
     pixeldata.SetPhotometricInterpretation( pi );
     //const Tag tpixeldata = Tag(0x7fe0, 0x0010);
     const PrivateTag tpixeldata(0x6003,0x0011,"GEMS_Ultrasound_ImageGroup_001");
@@ -484,10 +484,10 @@ void IconImageFilter::ExtractVeproIconImages()
 {
   const DataSet &rootds = F->GetDataSet();
 
-  const gdcm::PrivateTag ticon1(0x55,0x0030,"VEPRO VIF 3.0 DATA");
-  const gdcm::PrivateTag ticon2(0x55,0x0030,"VEPRO VIM 5.0 DATA");
+  const PrivateTag ticon1(0x55,0x0030,"VEPRO VIF 3.0 DATA");
+  const PrivateTag ticon2(0x55,0x0030,"VEPRO VIM 5.0 DATA");
 
-  const gdcm::ByteValue * bv = NULL;
+  const ByteValue * bv = NULL;
   // Prefer VIF over VIM ?
   if( rootds.FindDataElement( ticon1 ) )
     {
