@@ -35,14 +35,35 @@ ImageWriter::~ImageWriter()
 {
 }
 
-//void ImageWriter::SetImage(Image const &img)
-//{
-//  PixelData = img;
-//}
+MediaStorage ImageWriter::ComputeTargetMediaStorage()
+{
+  MediaStorage ms;
+  if( !ms.SetFromFile( GetFile() ) )
+  {
+    // Let's fix some old ACR-NEMA stuff:
+    ms = ImageHelper::ComputeMediaStorageFromModality( ms.GetModality(),
+        PixelData->GetNumberOfDimensions(),
+        PixelData->GetPixelFormat(),
+        PixelData->GetPhotometricInterpretation(),
+        GetImage().GetIntercept(), GetImage().GetSlope() );
+  }
+  // double check for MR Image Storage:
+  if( ms == MediaStorage::MRImageStorage &&
+    ( GetImage().GetIntercept() != 0.0 || GetImage().GetSlope() != 1.0 ) )
+  {
+    ms = ImageHelper::ComputeMediaStorageFromModality( ms.GetModality(),
+        PixelData->GetNumberOfDimensions(),
+        PixelData->GetPixelFormat(),
+        PixelData->GetPhotometricInterpretation(),
+        GetImage().GetIntercept(), GetImage().GetSlope() );
+  }
+  return ms;
+}
 
 bool ImageWriter::Write()
 {
-  if( !PrepareWrite() ) return false;
+  const MediaStorage ms = ComputeTargetMediaStorage();
+  if( !PrepareWrite( ms ) ) return false;
 
   //assert( Stream.is_open() );
   File& file = GetFile();
@@ -144,8 +165,6 @@ bool ImageWriter::Write()
     ds.Insert( de );
     }
 
-  MediaStorage ms;
-  ms.SetFromFile( GetFile() );
   assert( ms != MediaStorage::MS_END );
 
   // Patient Orientation
@@ -214,17 +233,22 @@ bool ImageWriter::Write()
 
   // Do the Rescale Intercept & Slope
   if( pi == PhotometricInterpretation::MONOCHROME1 || pi == PhotometricInterpretation::MONOCHROME2 )
-    {
+  {
     assert( pf.GetSamplesPerPixel() == 1 );
     ImageHelper::SetRescaleInterceptSlopeValue(GetFile(), pixeldata);
     if( ms == MediaStorage::RTDoseStorage && pixeldata.GetIntercept() != 0 )
-      {
+    {
       return false;
-      }
     }
+    else if( ms == MediaStorage::MRImageStorage && (pixeldata.GetIntercept() != 0 || pixeldata.GetSlope() != 1.0) )
+    {
+      if( !gdcm::ImageHelper::GetForceRescaleInterceptSlope() )
+        return false;
+    }
+  }
   else
     {
-    assert( pixeldata.GetIntercept() == 0 && pixeldata.GetSlope() == 1 );
+    gdcmAssertAlwaysMacro( pixeldata.GetIntercept() == 0 && pixeldata.GetSlope() == 1 );
     }
 
 //      Attribute<0x0028, 0x0006> planarconfiguration;
@@ -325,7 +349,7 @@ bool ImageWriter::Write()
     ds.Remove( Tag(0x0028, 0x1202) );
     ds.Remove( Tag(0x0028, 0x1203) );
 
-    // Dont' forget the segmented one:
+    // Don't forget the segmented one:
     ds.Remove( Tag(0x0028, 0x1221) );
     ds.Remove( Tag(0x0028, 0x1222) );
     ds.Remove( Tag(0x0028, 0x1223) );
