@@ -233,7 +233,7 @@ void JPEG2000Codec::SetRate(unsigned int idx, double rate)
 
 double JPEG2000Codec::GetRate(unsigned int idx ) const
 {
-  return Internals->coder_param.tcp_rates[idx];
+  return (double)Internals->coder_param.tcp_rates[idx];
 }
 
 void JPEG2000Codec::SetQuality(unsigned int idx, double q)
@@ -248,7 +248,7 @@ void JPEG2000Codec::SetQuality(unsigned int idx, double q)
 
 double JPEG2000Codec::GetQuality(unsigned int idx) const
 {
-  return Internals->coder_param.tcp_distoratio[idx];
+  return (double)Internals->coder_param.tcp_distoratio[idx];
 }
 
 void JPEG2000Codec::SetTileSize(unsigned int tx, unsigned int ty)
@@ -391,6 +391,34 @@ bool JPEG2000Codec::Decode(DataElement const &in, DataElement &out)
   return false;
 }
 
+static inline bool check_comp_valid(opj_image_t *image)
+{
+    int compno = 0;
+    opj_image_comp_t *comp = &image->comps[compno];
+    if (comp->prec > 32) // I doubt openjpeg will reach here.
+        return false;
+
+    bool invalid = false;
+    if (image->numcomps == 3)
+    {
+        opj_image_comp_t *comp1 = &image->comps[1];
+        opj_image_comp_t *comp2 = &image->comps[2];
+#if OPENJPEG_MAJOR_VERSION == 1
+        if (comp->bpp != comp1->bpp) invalid = true;
+        if (comp->bpp != comp2->bpp) invalid = true;
+#endif // OPENJPEG_MAJOR_VERSION == 1
+        if (comp->prec != comp1->prec) invalid = true;
+        if (comp->prec != comp2->prec) invalid = true;
+        if (comp->sgnd != comp1->sgnd) invalid = true;
+        if (comp->sgnd != comp2->sgnd) invalid = true;
+        if (comp->h != comp1->h) invalid = true;
+        if (comp->h != comp2->h) invalid = true;
+        if (comp->w != comp1->w) invalid = true;
+        if (comp->w != comp2->w) invalid = true;
+    }
+    return !invalid;
+}
+
 std::pair<char *, size_t> JPEG2000Codec::DecodeByStreamsCommon(char *dummy_buffer, size_t buf_size)
 {
   opj_dparameters_t parameters;  /* decompression parameters */
@@ -1016,7 +1044,7 @@ bool JPEG2000Codec::CodeFrameIntoBuffer(char * outdata, size_t outlen, size_t &
 
   myfile mysrc;
   myfile *fsrc = &mysrc;
-  char *buffer_j2k = new char[image_len]; // overallocated
+  char *buffer_j2k = new char[inputlength]; // overallocated
   fsrc->mem = fsrc->cur = buffer_j2k;
   fsrc->len = 0;
 
@@ -1156,34 +1184,6 @@ bool JPEG2000Codec::GetHeaderInfo(std::istream &is, TransferSyntax &ts)
   return b;
 }
 
-static inline bool check_comp_valid( opj_image_t *image )
-{
-  int compno = 0;
-  opj_image_comp_t *comp = &image->comps[compno];
-  if( comp->prec > 32 ) // I doubt openjpeg will reach here.
-    return false;
-
-  bool invalid = false;
-  if( image->numcomps == 3 )
-    {
-    opj_image_comp_t *comp1 = &image->comps[1];
-    opj_image_comp_t *comp2 = &image->comps[2];
-#if OPENJPEG_MAJOR_VERSION == 1
-    if( comp->bpp  != comp1->bpp  ) invalid = true;
-    if( comp->bpp  != comp2->bpp  ) invalid = true;
-#endif // OPENJPEG_MAJOR_VERSION == 1
-    if( comp->prec != comp1->prec ) invalid = true;
-    if( comp->prec != comp2->prec ) invalid = true;
-    if( comp->sgnd != comp1->sgnd ) invalid = true;
-    if( comp->sgnd != comp2->sgnd ) invalid = true;
-    if( comp->h != comp1->h ) invalid = true;
-    if( comp->h != comp2->h ) invalid = true;
-    if( comp->w != comp1->w ) invalid = true;
-    if( comp->w != comp2->w ) invalid = true;
-    }
-  return !invalid;
-}
-
 bool JPEG2000Codec::GetHeaderInfo(const char * dummy_buffer, size_t buf_size, TransferSyntax &ts)
 {
   opj_dparameters_t parameters;  /* decompression parameters */
@@ -1307,6 +1307,7 @@ bool JPEG2000Codec::GetHeaderInfo(const char * dummy_buffer, size_t buf_size, Tr
 #endif // OPENJPEG_MAJOR_VERSION == 1
 
   int reversible;
+  int mct;
 #if OPENJPEG_MAJOR_VERSION == 1
   opj_j2k_t* j2k = NULL;
   opj_jp2_t* jp2 = NULL;
@@ -1317,11 +1318,13 @@ bool JPEG2000Codec::GetHeaderInfo(const char * dummy_buffer, size_t buf_size, Tr
     j2k = (opj_j2k_t*)dinfo->j2k_handle;
     assert( j2k );
     reversible = j2k->cp->tcps->tccps->qmfbid;
+    mct = j2k->cp->tcps->mct;
     break;
   case JP2_CFMT:
     jp2 = (opj_jp2_t*)dinfo->jp2_handle;
     assert( jp2 );
     reversible = jp2->j2k->cp->tcps->tccps->qmfbid;
+    mct = jp2->j2k->cp->tcps->mct;
     break;
   default:
     gdcmErrorMacro( "Impossible happen" );
@@ -1330,6 +1333,8 @@ bool JPEG2000Codec::GetHeaderInfo(const char * dummy_buffer, size_t buf_size, Tr
 #else
   reversible = opj_get_reversible(dinfo, &parameters );
   assert( reversible == 0 || reversible == 1 );
+  // FIXME
+  assert( mct == 0 || mct == 1 );
 #endif // OPENJPEG_MAJOR_VERSION == 1
   LossyFlag = !reversible;
 
@@ -1421,7 +1426,10 @@ bool JPEG2000Codec::GetHeaderInfo(const char * dummy_buffer, size_t buf_size, Tr
     profiles. Note in particular that the JP2 file header is not sent in the JPEG
     2000 bitstream that is encapsulated in DICOM.
      */
-    PI = PhotometricInterpretation::YBR_RCT;
+    if( mct )
+      PI = PhotometricInterpretation::YBR_RCT;
+    else
+      PI = PhotometricInterpretation::RGB;
     this->PF.SetSamplesPerPixel( 3 );
     }
   else if( image->numcomps == 4 )
@@ -1440,10 +1448,10 @@ bool JPEG2000Codec::GetHeaderInfo(const char * dummy_buffer, size_t buf_size, Tr
     return false;
     }
 
-  assert( PI != PhotometricInterpretation::UNKNOW );
+  assert( PI != PhotometricInterpretation::UNKNOWN );
 
-  bool mct = false;
-  if( mct )
+  bool bmct = false;
+  if( bmct )
     {
     if( reversible )
       {
@@ -1602,7 +1610,7 @@ bool JPEG2000Codec::DecodeExtent(
       //std::streamoff relstart = is.tellg();
       //assert( relstart - thestart == 8 );
       std::streamoff off = frag.GetVL();
-      offsets.push_back( off );
+      offsets.push_back( (size_t)off );
       is.seekg( off, std::ios::cur );
       ++numfrags;
       }
@@ -1616,7 +1624,7 @@ bool JPEG2000Codec::DecodeExtent(
 
     for( unsigned int z = zmin; z <= zmax; ++z )
       {
-      size_t curoffset = std::accumulate( offsets.begin(), offsets.begin() + z, 0 );
+      size_t curoffset = std::accumulate( offsets.begin(), offsets.begin() + z, size_t(0) );
       is.seekg( thestart + curoffset + 8 * z, std::ios::beg );
       is.seekg( 8, std::ios::cur );
 
