@@ -241,7 +241,7 @@ bool JPEGCodec::Decode(DataElement const &in, DataElement &out)
       }
     }
   //assert( pos == len );
-  const size_t sizeOfOs = os.tellp();
+  const size_t sizeOfOs = (size_t)os.tellp();
   os.seekp( 0, std::ios::beg );
   ByteValue * bv = new ByteValue;
   bv->SetLength( (uint32_t)sizeOfOs );
@@ -573,8 +573,8 @@ bool JPEGCodec::DecodeExtent(
       {
       //std::streamoff relstart = is.tellg();
       //assert( relstart - thestart == 8 );
-      std::streamoff off = frag.GetVL();
-      offsets.push_back( off );
+      const std::streamoff off = frag.GetVL();
+      offsets.push_back( (size_t)off );
       is.seekg( off, std::ios::cur );
       ++numfrags;
       }
@@ -588,7 +588,7 @@ bool JPEGCodec::DecodeExtent(
 
     for( unsigned int z = zmin; z <= zmax; ++z )
       {
-      size_t curoffset = std::accumulate( offsets.begin(), offsets.begin() + z, 0 );
+      size_t curoffset = std::accumulate( offsets.begin(), offsets.begin() + z, size_t(0) );
       is.seekg( thestart + curoffset + 8 * z, std::ios::beg );
       is.seekg( 8, std::ios::cur );
 
