@@ -12,22 +12,22 @@
 #
 ############################################################################
 
-import gdcm
 import os,sys
+import gdcm
 
 def TestRead(filename, verbose = False):
   r = gdcm.Reader()
   r.SetFileName( filename )
-  sucess = r.Read()
+  success = r.Read()
   #if verbose: print r.GetFile()
   if verbose: print(r.GetFile().GetDataSet())
-  return sucess
+  return success
 
 if __name__ == "__main__":
-  sucess = 0
+  success = 0
   try:
     filename = os.sys.argv[1]
-    sucess += TestRead( filename, True )
+    success += TestRead( filename, True )
   except:
     # loop over all files:
     gdcm.Trace.DebugOff()
@@ -36,8 +36,8 @@ if __name__ == "__main__":
     nfiles = t.GetNumberOfFileNames()
     for i in range(0,nfiles):
       filename = t.GetFileName(i)
-      sucess += TestRead( filename )
+      success += TestRead( filename )
 
 
   # Test succeed ?
-  sys.exit(sucess == 0)
+  sys.exit(success == 0)
