@@ -29,6 +29,7 @@ static int TestImageRegionRead(const char* filename, bool verbose = false)
   // we need to read 3 attribute to detect the "well known" bug. However the third
   // attribute is (b500,b700) which make ReadUpToTag(7fe0,0010) fails...
   if( strcmp(fn.GetName(), "DMCPACS_ExplicitImplicit_BogusIOP.dcm" ) == 0
+    || strcmp(fn.GetName(), "SC16BitsAllocated_8BitsStoredJ2K.dcm" ) == 0 // mismatch pixel format in JPEG 200 vs DICOM
     || strcmp(fn.GetName(), "PHILIPS_Gyroscan-12-Jpeg_Extended_Process_2_4.dcm" ) == 0 ) // bogus JPEG cannot be streamed
     {
     std::cerr << "Skipping impossible file: " << filename << std::endl;
@@ -39,7 +40,7 @@ static int TestImageRegionRead(const char* filename, bool verbose = false)
   bool canReadInformation = reader.ReadInformation();
   if (!canReadInformation)
     {
-    std::cerr << "Cannot ReadInformation: " << filename << std::endl;
+    //std::cerr << "Cannot ReadInformation: " << filename << std::endl;
     return 0; //unable to read tags as expected.
     }
 
@@ -63,11 +64,11 @@ static int TestImageRegionRead(const char* filename, bool verbose = false)
   bool b = reader.ReadIntoBuffer(buffer, len);
   if( !b )
     {
-    std::cerr << "Could not ReadIntoBuffer" << std::endl;
+    std::cerr << "Could not ReadIntoBuffer: " << filename << std::endl;
     return 1;
     }
 #if 0
-  std::ofstream of( "/tmp/dd.raw" );
+  std::ofstream of( "/tmp/dd.raw", std::ios::binary );
   of.write( buffer, len );
   of.close();
 #endif
