@@ -46,7 +46,7 @@ static const char * const vtkgdcmMD5MetaImages[][3] = {
 { "LEADTOOLS_FLOWERS-8-PAL-Uncompressed.dcm","92629f1a782a3d10998d01a8af5df991", "16e999d6afc5574bcb075f296c3bcbbc" },
 { "D_CLUNIE_CT1_JPLL.dcm","74360148191955d7e5664952d85ad01c", "a109da372df2b85ff0a705fba62e9589" },
 { "DMCPACS_ExplicitImplicit_BogusIOP.dcm","3f434e2196fbe53d0024704c707254e9", "ef9f915086db838334ddc656a10486f2" },
-{ "PHILIPS_GDCM12xBug2.dcm","f3bb3e8fbf262a37621a805357b0b1c6", "a597540a79306be4710f4f04497fc23a" },
+{ "PHILIPS_GDCM12xBug2.dcm","7b17feb9fc02abf1ccfbef7be168c012", "22a1e3f971865b95ca7f367de094e680" },
 { "PICKER-16-MONO2-Nested_icon.dcm","2642d6b9be2d28d57f85abffc661bdb7", "954c99e48a083cc54de16ad07d553005" },
 { "RadBWLossLess.dcm","1cbcd5c44f8ffe7c448520971233afb4", "dbbf39ac11a39372b1e961f40ac6f62a" },
 { "gdcm-JPEG-Extended.dcm","4873a6ad617c2a8f86d130c853c5e127", "f05174b105604a462af0fa733fceebde" },
@@ -92,7 +92,7 @@ static const char * const vtkgdcmMD5MetaImages[][3] = {
 { "LJPEG_BuginGDCM12.dcm","fb9e4419f90eaa9c2a6c4ae98b750348", "9214cc4f62fbea873ffad88e1be877c5" },
 { "XA-MONO2-8-12x-catheter.dcm","639e46ee89a1204df2ed708e33c3357b", "136eaf8f7d654bbb08741c201a945561" },
 { "LEADTOOLS_FLOWERS-16-MONO2-Uncompressed.dcm","e086859c0b556c3d22d51bf2a05db26a", "70166425c4dca767e22d3f25f737922b" },
-{ "TheralysGDCM120Bug.dcm","3bbfb2b54ec9d9e3f89fe046e5a954a4", "6af53848fe77feb56a12aba74dadea8e" },
+{ "TheralysGDCM120Bug.dcm","e656263a9a475027fd356a30c26979d1", "d92b88a18dc63add8265ad338f8a58e9" },
 { "D_CLUNIE_VL1_RLE.dcm","668904d73866455812fee0aabdbcff1e", "b07e34ec35ba1be62ee7d4a404cf0b90" },
 { "D_CLUNIE_MR1_JPLL.dcm","087e123efb3e18f5e7693390926f08c6", "7b7424e6115931c371f3c94c2f5d32d9" },
 { "GE_DLX-8-MONO2-Multiframe-Jpeg_Lossless.dcm","61c2a3757ad053c52eeeaa94f5d6cadd", "b8bcbccd17b76a0f8e3d4c342f855f9f" },
@@ -118,7 +118,7 @@ static const char * const vtkgdcmMD5MetaImages[][3] = {
 { "CT-MONO2-16-ankle.dcm","803a459d3a6df6473c3f3e46129df147", "13e853d75ffe289b8210d1336e2394dd" },
 { "MR_ELSCINT1_00e1_1042_SQ_feff_00e0_Item.dcm","4bb845dfa4b1f9b46fa53006e82bf4c8", "4d790e17ee35572d64e37c55dbc36725" },
 { "LEADTOOLS_FLOWERS-24-RGB-JpegLossy.dcm","e91814bf121ae0dad75be63fbf1b1e93", "38c2784aa485733fef45b6517479a4f5" },
-{ "undefined_length_un_vr.dcm","fd3d95cd61c0fc391733f28f607fa506", "e0221ddcc9febdc3c266bb8cd0fcf14f" },
+{ "undefined_length_un_vr.dcm","88cbd399556f1ac8172153400f0eaf2f", "99cae85becc9b35b9385297c9a4b3708" },
 { "JPEG_LossyYBR.dcm","351424d0392db74bc69cf6f6537ddb88", "d6fb1fb06318dd305a461db9c84cf825" },
 { "rle16loo.dcm","fd66e0089e5c343d3f24642710eb0129", "04b42f011bdcf56e8a22607cb715447c" },
 { "D_CLUNIE_MR2_JPLY.dcm","013b4754a4224b10cb503dead5a6a79e", "981510df3a57e98141c7d192b45bd93f" },
@@ -155,11 +155,11 @@ static const char * const vtkgdcmMD5MetaImages[][3] = {
 { "US-RGB-8-esopecho.dcm","0916c89d6e3f3f28a52933829e5d0b3c", "4b350b9353a93c747917c7c3bf9b8f44" },
 { "FUJI-10-MONO1-ACR_NEMA_2.dcm","98190f9abe6cdf82e565aee55288aaba", "da2415a1e58b4ca2e588d0de18274f60" },
 { "JDDICOM_Sample2-dcmdjpeg.dcm","d883a2a8e69820f465865200cc726a4f", "33aa469ec024188d692262d03e7108a0" },
-{ "MR_Philips_Intera_PrivateSequenceImplicitVR.dcm","f89bb9670acce806d40f84e15a3143b0", "f69bca6228b0ca07d97ee11c0ab3b989" },
+{ "MR_Philips_Intera_PrivateSequenceImplicitVR.dcm","a98b2a5739a8956a6a811fcfcf988f60", "c6f98b5a0aac88e16b211981a6074a43" },
 { "D_CLUNIE_RG2_JPLY.dcm","e4e64e50877ce1134a58824e4b3b0cda", "27fa50d4cf6b31baa669e9746ce10f63" },
 { "ITK_GDCM124_MultiframeSecondaryCaptureInvalid.dcm","31a2d7476b505c01d77bf06333a3b797", "83601a7a4fa987c61b865b4b92f3caa0" },
 { "GE_RHAPSODE-16-MONO2-JPEG-Fragments.dcm","12d33998ab1c371f3c2401fa362b2663", "a109da372df2b85ff0a705fba62e9589" },
-{ "PHILIPS_GDCM12xBug.dcm","7a2531acbdaf8053365099a844f46df8", "d7673c8575cb2765f8ae25aa3899c77e" },
+{ "PHILIPS_GDCM12xBug.dcm","c119395093c64d50d1c2aad34d99d08e", "396d74c4589f18bb26b14a7006eb9d8a" },
 { "OT-PAL-8-face.dcm","42c16b6897e32fbac5fd68a2d2523642", "d7c30d57af821b02c67103250a744235" },
 { "D_CLUNIE_SC1_JPLY.dcm","46dc0d3ad79883f0f5866ceeeb43c979", "994a5abb70d3f5968672ce4970a9d4da" },
 { "CT-MONO2-8-abdo.dcm","e94fa94ff3b7a34db63d40790995ce9c", "86d3e09a5858aa3844cb3be1b822a069" },
@@ -215,6 +215,9 @@ static const char * const vtkgdcmMD5MetaImages[][3] = {
 { "NM-PAL-16-PixRep1.dcm","a04de15a87306cf77cd85ae5b720a0b2", "304f147752d46adfdcff71a30cd03d0a" },
 { "MEDILABInvalidCP246_EVRLESQasUN.dcm","da13f42e41d36ef065af2cb5d770f70b", "d99ace99196e148522c8599803bacc28" },
 { "JPEGInvalidSecondFrag.dcm","32ea68aea0c81d4cc75c5a234e1719ed", "8fb3a76c1f18b71b52d139ebd8406b50" },
+{ "SC16BitsAllocated_8BitsStoredJPEG.dcm","c9f9d07783496fa9a9e5b28a90603a70", "c164a73ba18ab4e88977921ffc7c3a65" },
+{ "SC16BitsAllocated_8BitsStoredJ2K.dcm","96639bac776d875b02f6aa9b35ee2db7", "dbf83984984741c98205d77a947b442c" },
+{ "SIEMENS_SYNGO-12-MONO2-LUTWrongLength512.dcm","81f79e2fcb3caec752e55be8077441dc", "4a5d8549791432b29948dd8ff63e2534" },
 
 
 /* Stopping condition */
